@@ -5,16 +5,21 @@ from __future__ import annotations
 import os
 import re
 import sys
+import warnings
 from contextlib import contextmanager
-from functools import partial, wraps
+from functools import partial
 from importlib.metadata import version as pkgversion
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable
+from random import sample
+from tempfile import gettempdir
+from typing import TYPE_CHECKING
 
 from duty import duty, tools
+from pysource_codegen import generate
+from pysource_minimize import minimize
 
 if TYPE_CHECKING:
-    from collections.abc import Callable, Iterator
+    from collections.abc import Iterator
 
     from duty.context import Context
 
@@ -26,6 +31,8 @@ CI = os.environ.get("CI", "0") in {"1", "true", "yes", ""}
 WINDOWS = os.name == "nt"
 PTY = not WINDOWS and not CI
 MULTIRUN = os.environ.get("MULTIRUN", "0") == "1"
+PY_VERSION = f"{sys.version_info.major}{sys.version_info.minor}"
+PY_DEV = "314"
 
 
 def _pyprefix(title: str) -> str:
@@ -35,21 +42,6 @@ def _pyprefix(title: str) -> str:
     return title
 
 
-def _not_from_insiders(func: Callable) -> Callable:
-    @wraps(func)
-    def wrapper(ctx: Context, *args: Any, **kwargs: Any) -> None:
-        origin = ctx.run("git config --get remote.origin.url", silent=True)
-        if "pawamoy-insiders/griffe" in origin:
-            ctx.run(
-                lambda: False,
-                title="Not running this task from insiders repository (do that from public repo instead!)",
-            )
-            return
-        func(ctx, *args, **kwargs)
-
-    return wrapper
-
-
 @contextmanager
 def _material_insiders() -> Iterator[bool]:
     if "+insiders" in pkgversion("mkdocs-material"):
@@ -128,7 +120,7 @@ def check(ctx: Context) -> None:
     """
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_quality(ctx: Context) -> None:
     """Check the code quality.
 
@@ -196,7 +188,7 @@ def check_quality(ctx: Context) -> None:
     )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_docs(ctx: Context) -> None:
     """Check if the documentation builds correctly.
 
@@ -215,6 +207,8 @@ def check_docs(ctx: Context) -> None:
     """
     Path("htmlcov").mkdir(parents=True, exist_ok=True)
     Path("htmlcov/index.html").touch(exist_ok=True)
+    if CI:
+        os.environ["DEPLOY"] = "true"
     with _material_insiders():
         ctx.run(
             tools.mkdocs.build(strict=True, verbose=True),
@@ -222,7 +216,7 @@ def check_docs(ctx: Context) -> None:
         )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_types(ctx: Context) -> None:
     """Check that the code is correctly typed.
 
@@ -273,7 +267,7 @@ def check_types(ctx: Context) -> None:
     )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_api(ctx: Context, *cli_args: str) -> None:
     """Check for API breaking changes.
 
@@ -291,7 +285,17 @@ def check_api(ctx: Context, *cli_args: str) -> None:
         *cli_args: Additional Griffe CLI arguments.
     """
     ctx.run(
-        tools.griffe.check("griffe", search=["src"], color=True).add_args(*cli_args),
+        tools.griffe.check(
+            "griffe",
+            search=["src"],
+            color=True,
+            extensions=[
+                "griffe_inherited_docstrings",
+                # YORE: Bump 2: Remove line.
+                "scripts/griffe_exts.py",
+                "unpack_typeddict",
+            ],
+        ).add_args(*cli_args),
         title="Checking for API breaking changes",
         nofail=True,
     )
@@ -321,7 +325,7 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
 
 
 @duty
-def docs_deploy(ctx: Context, *, force: bool = False) -> None:
+def docs_deploy(ctx: Context) -> None:
     """Deploy the documentation to GitHub pages.
 
     ```bash
@@ -329,37 +333,12 @@ def docs_deploy(ctx: Context, *, force: bool = False) -> None:
     ```
 
     Use [MkDocs](https://www.mkdocs.org/) to build and deploy the documentation to GitHub pages.
-
-    Parameters:
-        force: Whether to force deployment, even from non-Insiders version.
     """
     os.environ["DEPLOY"] = "true"
     with _material_insiders() as insiders:
         if not insiders:
             ctx.run(lambda: False, title="Not deploying docs without Material for MkDocs Insiders!")
-        origin = ctx.run("git config --get remote.origin.url", silent=True, allow_overrides=False)
-        if "pawamoy-insiders/griffe" in origin:
-            ctx.run(
-                "git remote add upstream git@github.com:mkdocstrings/griffe",
-                silent=True,
-                nofail=True,
-                allow_overrides=False,
-            )
-            ctx.run(
-                tools.mkdocs.gh_deploy(remote_name="upstream", force=True),
-                title="Deploying documentation",
-            )
-        elif force:
-            ctx.run(
-                tools.mkdocs.gh_deploy(force=True),
-                title="Deploying documentation",
-            )
-        else:
-            ctx.run(
-                lambda: False,
-                title="Not deploying docs from public repository (do that from insiders instead!)",
-                nofail=True,
-            )
+        ctx.run(tools.mkdocs.gh_deploy(force=True), title="Deploying documentation")
 
 
 @duty
@@ -401,7 +380,6 @@ def build(ctx: Context) -> None:
 
 
 @duty
-@_not_from_insiders
 def publish(ctx: Context) -> None:
     """Publish source and wheel distributions to PyPI.
 
@@ -423,7 +401,6 @@ def publish(ctx: Context) -> None:
 
 
 @duty(post=["build", "publish", "docs-deploy"])
-@_not_from_insiders
 def release(ctx: Context, version: str = "") -> None:
     """Release a new version of the project.
 
@@ -448,7 +425,7 @@ def release(ctx: Context, version: str = "") -> None:
         ctx.run("false", title="A version must be provided")
     ctx.run("git add pyproject.toml CHANGELOG.md", title="Staging files", pty=PTY)
     ctx.run(["git", "commit", "-m", f"chore: Prepare release {version}"], title="Committing changes", pty=PTY)
-    ctx.run(f"git tag {version}", title="Tagging commit", pty=PTY)
+    ctx.run(f"git tag -m '' -a {version}", title="Tagging commit", pty=PTY)
     ctx.run("git push", title="Pushing commits", pty=False)
     ctx.run("git push --tags", title="Pushing tags", pty=False)
 
@@ -470,12 +447,12 @@ def coverage(ctx: Context) -> None:
     ctx.run(tools.coverage.html(rcfile="config/coverage.ini"))
 
 
-@duty
-def test(ctx: Context, *cli_args: str, match: str = "") -> None:
+@duty(nofail=PY_VERSION == PY_DEV)
+def test(ctx: Context, *cli_args: str) -> None:
     """Run the test suite.
 
     ```bash
-    make test [match=EXPR]
+    make test
     ```
 
     Run the test suite with [Pytest](https://docs.pytest.org/) and plugins.
@@ -484,15 +461,13 @@ def test(ctx: Context, *cli_args: str, match: str = "") -> None:
 
     Parameters:
         *cli_args: Additional Pytest CLI arguments.
-        match: A pytest expression to filter selected tests.
     """
-    py_version = f"{sys.version_info.major}{sys.version_info.minor}"
-    os.environ["COVERAGE_FILE"] = f".coverage.{py_version}"
+    os.environ["COVERAGE_FILE"] = f".coverage.{PY_VERSION}"
+    os.environ["PYTHONWARNDEFAULTENCODING"] = "1"
     ctx.run(
         tools.pytest(
             "tests",
             config_file="config/pytest.ini",
-            select=match,
             color="yes",
         ).add_args("-n", "auto", *cli_args),
         title=_pyprefix("Running tests"),
@@ -523,14 +498,7 @@ def fuzz(
         min_seed: Minimum value for the seeds range.
         max_seed: Maximum value for the seeds range.
     """
-    import warnings
-    from random import sample
-    from tempfile import gettempdir
-
-    from pysource_codegen import generate
-    from pysource_minimize import minimize
-
-    from griffe import visit
+    from griffe import visit  # noqa: PLC0415
 
     warnings.simplefilter("ignore", SyntaxWarning)
 
