@@ -22,7 +22,7 @@ def _render_call_graph(module: Path) -> None:
     buffer = StringIO()
     code2flow(str(module), buffer)
     try:
-        svg = subprocess.check_output(["dot", "-Tsvg"], input=buffer.getvalue(), text=True)  # noqa: S603, S607
+        svg = subprocess.check_output(["dot", "-Tsvg"], input=buffer.getvalue(), text=True)  # noqa: S607
     except subprocess.CalledProcessError:
         # The subprocess dies with SIGSEGV in GHA...
         return
@@ -69,7 +69,7 @@ def render_internal_api(heading_level: int = 4) -> None:
     """
     root = Path(os.environ["MKDOCS_CONFIG_DIR"])
     src = root / "src"
-    internal_api = src / "_griffe"
+    internal_api = src / "griffe" / "_internal"
     print(_comment_block(internal_api / "__init__.py"))
     _render_api(internal_api, internal_api, heading_level)
 
