@@ -12,7 +12,9 @@ from typing import TYPE_CHECKING, Any, Callable
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
-PYTHON_VERSIONS = os.getenv("PYTHON_VERSIONS", "3.9 3.10 3.11 3.12 3.13 3.14").split()
+
+PYTHON_VERSIONS = os.getenv("PYTHON_VERSIONS", "3.10 3.11 3.12 3.13 3.14 3.15").split()
+PYTHON_DEV = "3.15"
 
 _commands = []
 
@@ -49,12 +51,21 @@ def _uv_install(venv: Path) -> None:
 def _run(version: str, cmd: str, *args: str, **kwargs: Any) -> None:
     kwargs = {"check": True, **kwargs}
     uv_run = ["uv", "run", "--no-sync"]
-    if version == "default":
-        with _environ(UV_PROJECT_ENVIRONMENT=".venv"):
-            subprocess.run([*uv_run, cmd, *args], **kwargs)  # noqa: S603, PLW1510
-    else:
-        with _environ(UV_PROJECT_ENVIRONMENT=f".venvs/{version}", MULTIRUN="1"):
-            subprocess.run([*uv_run, cmd, *args], **kwargs)  # noqa: S603, PLW1510
+    try:
+        if version == "default":
+            with _environ(UV_PROJECT_ENVIRONMENT=".venv"):
+                subprocess.run([*uv_run, cmd, *args], **kwargs)  # noqa: S603, PLW1510
+        else:
+            with _environ(UV_PROJECT_ENVIRONMENT=f".venvs/{version}", MULTIRUN="1"):
+                subprocess.run([*uv_run, cmd, *args], **kwargs)  # noqa: S603, PLW1510
+    except subprocess.CalledProcessError as process:
+        raise _RunError(
+            returncode=process.returncode,
+            python_version=version,
+            cmd=process.cmd,
+            output=process.output,
+            stderr=process.stderr,
+        ) from process
 
 
 def _command(name: str) -> Callable[[Callable[..., None]], Callable[..., None]]:
@@ -118,7 +129,7 @@ def setup() -> None:
 
     Once dependencies are installed, try running `make` or `make help` again, to show additional tasks.
 
-    ```console exec="1" source="console"
+    ```console exec="1" source="console" id="make-help2"
     $ alias make="$PWD/scripts/make"  # markdown-exec: hide
     $ make
     ```
@@ -148,6 +159,12 @@ def setup() -> None:
                 _uv_install(venv_path)
 
 
+class _RunError(subprocess.CalledProcessError):
+    def __init__(self, *args: Any, python_version: str, **kwargs: Any):
+        super().__init__(*args, **kwargs)
+        self.python_version = python_version
+
+
 @_command("run")
 def run(cmd: str, *args: str, **kwargs: Any) -> None:
     """Run a command in the default virtual environment.
@@ -277,19 +294,31 @@ def main(args: list[str]) -> int:
         cmd = args.pop(0)
 
         if cmd == "run":
-            run(*args)
+            if not args:
+                print("make: run: missing command", file=sys.stderr)
+                return 1
+            run(*args)  # ty: ignore[missing-argument]
             return 0
 
         if cmd == "multirun":
-            multirun(*args)
+            if not args:
+                print("make: run: missing command", file=sys.stderr)
+                return 1
+            multirun(*args)  # ty: ignore[missing-argument]
             return 0
 
         if cmd == "allrun":
-            allrun(*args)
+            if not args:
+                print("make: run: missing command", file=sys.stderr)
+                return 1
+            allrun(*args)  # ty: ignore[missing-argument]
             return 0
 
         if cmd.startswith("3."):
-            run3x(cmd, *args)
+            if not args:
+                print("make: run: missing command", file=sys.stderr)
+                return 1
+            run3x(cmd, *args)  # ty: ignore[missing-argument]
             return 0
 
         opts = []
@@ -316,7 +345,14 @@ def main(args: list[str]) -> int:
 if __name__ == "__main__":
     try:
         sys.exit(main(sys.argv[1:]))
-    except subprocess.CalledProcessError as process:
+    except _RunError as process:
         if process.output:
             print(process.output, file=sys.stderr)
-        sys.exit(process.returncode)
+        if (code := process.returncode) == 139:  # noqa: PLR2004
+            print(
+                f"✗ (python{process.python_version})  '{' '.join(process.cmd)}' failed with return code {code} (segfault)",
+                file=sys.stderr,
+            )
+            if process.python_version == PYTHON_DEV:
+                code = 0
+        sys.exit(code)
