@@ -127,10 +127,12 @@ Griffe provides a few helpers to extract expressions from regular AST nodes.
 
 - [`griffe.get_annotation`][]: Get a type annotation as expression.
 - [`griffe.get_base_class`][]: Get a base class as expression.
+- [`griffe.get_class_keyword`][]: Get a class keyword as expression.
 - [`griffe.get_condition`][]: Get a condition as expression.
 - [`griffe.get_expression`][]: Get an expression from an AST node.
 - [`griffe.safe_get_annotation`][]: Get a type annotation as expression, safely (returns `None` on error).
 - [`griffe.safe_get_base_class`][]: Get a base class as expression, safely (returns `None` on error).
+- [`griffe.safe_get_class_keyword`][]: Get a class keyword as expression, safely (returns `None` on error).
 - [`griffe.safe_get_condition`][]: Get a condition as expression, safely (returns `None` on error).
 - [`griffe.safe_get_expression`][]: Get an expression from an AST node, safely (returns `None` on error).
 
@@ -162,9 +164,12 @@ To test your Griffe extensions, or to load API data from code in memory, Griffe
 
 from __future__ import annotations
 
-from _griffe.agents.inspector import Inspector, inspect
-from _griffe.agents.nodes.assignments import get_instance_names, get_name, get_names
-from _griffe.agents.nodes.ast import (
+import warnings
+from typing import Any
+
+from griffe._internal.agents.inspector import Inspector, inspect
+from griffe._internal.agents.nodes.assignments import get_instance_names, get_name, get_names
+from griffe._internal.agents.nodes.ast import (
     ast_children,
     ast_first_child,
     ast_kind,
@@ -175,19 +180,19 @@ from _griffe.agents.nodes.ast import (
     ast_previous_siblings,
     ast_siblings,
 )
-from _griffe.agents.nodes.docstrings import get_docstring
+from griffe._internal.agents.nodes.docstrings import get_docstring
 
 # YORE: Bump 2: Replace `ExportedName, ` with `` within line.
-from _griffe.agents.nodes.exports import ExportedName, get__all__, safe_get__all__
-from _griffe.agents.nodes.imports import relative_to_absolute
-from _griffe.agents.nodes.parameters import ParametersType, get_parameters
-from _griffe.agents.nodes.runtime import ObjectNode
-from _griffe.agents.nodes.values import get_value, safe_get_value
-from _griffe.agents.visitor import Visitor, builtin_decorators, stdlib_decorators, typing_overload, visit
-from _griffe.c3linear import c3linear_merge
-from _griffe.cli import DEFAULT_LOG_LEVEL, check, dump, get_parser, main
-from _griffe.collections import LinesCollection, ModulesCollection
-from _griffe.diff import (
+from griffe._internal.agents.nodes.exports import ExportedName, get__all__, safe_get__all__
+from griffe._internal.agents.nodes.imports import relative_to_absolute
+from griffe._internal.agents.nodes.parameters import ParametersType, get_parameters
+from griffe._internal.agents.nodes.runtime import ObjectNode
+from griffe._internal.agents.nodes.values import get_value, safe_get_value
+from griffe._internal.agents.visitor import Visitor, builtin_decorators, stdlib_decorators, typing_overload, visit
+from griffe._internal.c3linear import c3linear_merge
+from griffe._internal.cli import DEFAULT_LOG_LEVEL, check, dump, get_parser, main
+from griffe._internal.collections import LinesCollection, ModulesCollection
+from griffe._internal.diff import (
     AttributeChangedTypeBreakage,
     AttributeChangedValueBreakage,
     Breakage,
@@ -203,8 +208,15 @@ from _griffe.diff import (
     ReturnChangedTypeBreakage,
     find_breaking_changes,
 )
-from _griffe.docstrings.google import parse_google
-from _griffe.docstrings.models import (
+from griffe._internal.docstrings.auto import (
+    AutoOptions,
+    DocstringDetectionMethod,
+    PerStyleOptions,
+    infer_docstring_style,
+    parse_auto,
+)
+from griffe._internal.docstrings.google import GoogleOptions, parse_google
+from griffe._internal.docstrings.models import (
     DocstringAdmonition,
     DocstringAttribute,
     DocstringClass,
@@ -231,24 +243,26 @@ from _griffe.docstrings.models import (
     DocstringSectionReceives,
     DocstringSectionReturns,
     DocstringSectionText,
+    DocstringSectionTypeAliases,
+    DocstringSectionTypeParameters,
     DocstringSectionWarns,
     DocstringSectionYields,
+    DocstringTypeAlias,
+    DocstringTypeParameter,
     DocstringWarn,
     DocstringYield,
 )
-from _griffe.docstrings.numpy import parse_numpy
-from _griffe.docstrings.parsers import (
-    DocstringDetectionMethod,
+from griffe._internal.docstrings.numpy import NumpyOptions, parse_numpy
+from griffe._internal.docstrings.parsers import (
+    DocstringOptions,
     DocstringStyle,
-    infer_docstring_style,
     parse,
-    parse_auto,
     parsers,
 )
-from _griffe.docstrings.sphinx import parse_sphinx
-from _griffe.docstrings.utils import docstring_warning, parse_docstring_annotation
-from _griffe.encoders import JSONEncoder, json_decoder
-from _griffe.enumerations import (
+from griffe._internal.docstrings.sphinx import SphinxOptions, parse_sphinx
+from griffe._internal.docstrings.utils import docstring_warning, parse_docstring_annotation
+from griffe._internal.encoders import JSONEncoder, json_decoder
+from griffe._internal.enumerations import (
     BreakageKind,
     DocstringSectionKind,
     ExplanationStyle,
@@ -257,8 +271,9 @@ from _griffe.enumerations import (
     ObjectKind,
     ParameterKind,
     Parser,
+    TypeParameterKind,
 )
-from _griffe.exceptions import (
+from griffe._internal.exceptions import (
     AliasResolutionError,
     BuiltinModuleError,
     CyclicAliasError,
@@ -273,7 +288,7 @@ from _griffe.exceptions import (
     UnhandledEditableModuleError,
     UnimportableModuleError,
 )
-from _griffe.expressions import (
+from griffe._internal.expressions import (
     Expr,
     ExprAttribute,
     ExprBinOp,
@@ -308,35 +323,38 @@ from _griffe.expressions import (
     ExprYieldFrom,
     get_annotation,
     get_base_class,
+    get_class_keyword,
     get_condition,
     get_expression,
     safe_get_annotation,
     safe_get_base_class,
+    safe_get_class_keyword,
     safe_get_condition,
     safe_get_expression,
 )
-from _griffe.extensions.base import (
+from griffe._internal.extensions.base import (
     Extension,
     Extensions,
     LoadableExtensionType,
     builtin_extensions,
     load_extensions,
 )
-from _griffe.extensions.dataclasses import DataclassesExtension
-from _griffe.finder import ModuleFinder, NamePartsAndPathType, NamePartsType, NamespacePackage, Package
-from _griffe.git import assert_git_repo, get_latest_tag, get_repo_root, tmp_worktree
-from _griffe.importer import dynamic_import, sys_path
-from _griffe.loader import GriffeLoader, load, load_git, load_pypi
-from _griffe.logger import Logger, get_logger, logger, patch_loggers
-from _griffe.merger import merge_stubs
-from _griffe.mixins import (
+from griffe._internal.extensions.dataclasses import DataclassesExtension
+from griffe._internal.extensions.unpack_typeddict import UnpackTypedDictExtension
+from griffe._internal.finder import ModuleFinder, NamePartsAndPathType, NamePartsType, NamespacePackage, Package
+from griffe._internal.git import GitInfo, KnownGitService
+from griffe._internal.importer import dynamic_import, sys_path
+from griffe._internal.loader import GriffeLoader, load, load_git, load_pypi
+from griffe._internal.logger import Logger, get_logger, logger, patch_loggers
+from griffe._internal.merger import merge_stubs
+from griffe._internal.mixins import (
     DelMembersMixin,
     GetMembersMixin,
     ObjectAliasMixin,
     SerializationMixin,
     SetMembersMixin,
 )
-from _griffe.models import (
+from griffe._internal.models import (
     Alias,
     Attribute,
     Class,
@@ -347,9 +365,12 @@ from _griffe.models import (
     Object,
     Parameter,
     Parameters,
+    TypeAlias,
+    TypeParameter,
+    TypeParameters,
 )
-from _griffe.stats import Stats
-from _griffe.tests import (
+from griffe._internal.stats import Stats
+from griffe._internal.tests import (
     TmpPackage,
     htree,
     module_vtree,
@@ -362,9 +383,33 @@ from _griffe.tests import (
     vtree,
 )
 
+# YORE: Bump 2: Remove block.
+_deprecated_names = (
+    "assert_git_repo",
+    "get_latest_tag",
+    "get_repo_root",
+    "tmp_worktree",
+)
+
+
+# YORE: Bump 2: Remove block.
+def __getattr__(name: str) -> Any:
+    if name in _deprecated_names:
+        from griffe._internal import git  # noqa: PLC0415
+
+        warnings.warn(
+            f"The `{name}` function is deprecated and will become unavailable in the next major version.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return getattr(git, f"_{name}")
+
+    raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
+
+
 # Regenerate this list with the following Python snippet:
 # import griffe
-# names = sorted(n for n in dir(griffe) if not n.startswith("_") and n not in ("annotations", "lazy_importing"))
+# names = sorted(n for n in dir(griffe) if not n.startswith("_") and n not in ("Any", "annotations", "lazy_importing", "warnings"))
 # print('__all__ = [\n    "' + '",\n    "'.join(names) + '",\n]')
 __all__ = [
     "DEFAULT_LOG_LEVEL",
@@ -373,6 +418,7 @@ __all__ = [
     "Attribute",
     "AttributeChangedTypeBreakage",
     "AttributeChangedValueBreakage",
+    "AutoOptions",
     "Breakage",
     "BreakageKind",
     "BuiltinModuleError",
@@ -392,6 +438,7 @@ __all__ = [
     "DocstringFunction",
     "DocstringModule",
     "DocstringNamedElement",
+    "DocstringOptions",
     "DocstringParameter",
     "DocstringRaise",
     "DocstringReceive",
@@ -411,9 +458,13 @@ __all__ = [
     "DocstringSectionReceives",
     "DocstringSectionReturns",
     "DocstringSectionText",
+    "DocstringSectionTypeAliases",
+    "DocstringSectionTypeParameters",
     "DocstringSectionWarns",
     "DocstringSectionYields",
     "DocstringStyle",
+    "DocstringTypeAlias",
+    "DocstringTypeParameter",
     "DocstringWarn",
     "DocstringYield",
     "ExplanationStyle",
@@ -458,11 +509,14 @@ __all__ = [
     "Function",
     "GetMembersMixin",
     "GitError",
+    "GitInfo",
+    "GoogleOptions",
     "GriffeError",
     "GriffeLoader",
     "Inspector",
     "JSONEncoder",
     "Kind",
+    "KnownGitService",
     "LastNodeError",
     "LinesCollection",
     "LoadableExtensionType",
@@ -476,6 +530,7 @@ __all__ = [
     "NamePartsType",
     "NameResolutionError",
     "NamespacePackage",
+    "NumpyOptions",
     "Object",
     "ObjectAliasMixin",
     "ObjectChangedKindBreakage",
@@ -494,14 +549,21 @@ __all__ = [
     "Parameters",
     "ParametersType",
     "Parser",
+    "PerStyleOptions",
     "ReturnChangedTypeBreakage",
     "RootNodeError",
     "SerializationMixin",
     "SetMembersMixin",
+    "SphinxOptions",
     "Stats",
     "TmpPackage",
+    "TypeAlias",
+    "TypeParameter",
+    "TypeParameterKind",
+    "TypeParameters",
     "UnhandledEditableModuleError",
     "UnimportableModuleError",
+    "UnpackTypedDictExtension",
     "Visitor",
     "assert_git_repo",
     "ast_children",
@@ -524,6 +586,7 @@ __all__ = [
     "get__all__",
     "get_annotation",
     "get_base_class",
+    "get_class_keyword",
     "get_condition",
     "get_docstring",
     "get_expression",
@@ -560,6 +623,7 @@ __all__ = [
     "safe_get__all__",
     "safe_get_annotation",
     "safe_get_base_class",
+    "safe_get_class_keyword",
     "safe_get_condition",
     "safe_get_expression",
     "safe_get_value",
