@@ -7,7 +7,7 @@
 
 import sys
 
-from _griffe.cli import main
+from griffe._internal.cli import main
 
 if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
