@@ -15,6 +15,12 @@ from griffe import (
     DocstringRaise,
     DocstringReturn,
     DocstringSectionKind,
+    Expr,
+    ExprAttribute,
+    ExprBinOp,
+    ExprName,
+    ExprSubscript,
+    ExprTuple,
     Function,
     Module,
     Parameter,
@@ -231,28 +237,62 @@ def test_parse__param_field_docs_type__param_section_with_type(parse_sphinx: Par
     assert actual.as_dict() == expected.as_dict()
 
 
-def test_parse__param_field_type_field__param_section_with_type(parse_sphinx: ParserType) -> None:
+@pytest.mark.parametrize("type_", ["str", "int"])
+def test_parse__param_field_type_field__param_section_with_type(parse_sphinx: ParserType, type_: str) -> None:
     """Parse parameters with separated types.
 
     Parameters:
         parse_sphinx: Fixture parser.
+        type_: The type to use in the type directive.
     """
     docstring = f"""
         Docstring with line continuation.
 
-        :param foo: {SOME_TEXT}
-        :type foo: str
+        :param {SOME_NAME}: {SOME_TEXT}
+        :type {SOME_NAME}: {type_}
     """
 
     sections, _ = parse_sphinx(docstring)
     assert len(sections) == 2
     assert sections[1].kind is DocstringSectionKind.parameters
     actual = sections[1].value[0]
-    expected = DocstringParameter(SOME_NAME, annotation="str", description=SOME_TEXT)
+    expected = DocstringParameter(SOME_NAME, annotation=f"{type_}", description=SOME_TEXT)
     assert isinstance(actual, type(expected))
     assert actual.as_dict() == expected.as_dict()
 
 
+@pytest.mark.parametrize("type_", ["str", "int"])
+def test_parse__param_field_type_field__param_section_with_type_with_parent(
+    parse_sphinx: ParserType,
+    type_: str,
+) -> None:
+    """Parse parameters with separated types.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+        type_: The type to use in the type directive.
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :param {SOME_NAME}: {SOME_TEXT}
+        :type {SOME_NAME}: {type_}
+    """
+    parent_fn = Function("func", parameters=Parameters(Parameter(SOME_NAME)))
+    sections, _ = parse_sphinx(docstring, parent=parent_fn)
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    expected_annotation = ExprName(name=f"{type_}")
+    expected = DocstringParameter(SOME_NAME, annotation=expected_annotation, description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+    assert isinstance(actual.annotation, type(expected.annotation))
+    assert isinstance(actual.annotation, ExprName)
+    assert isinstance(actual.annotation, Expr)
+    assert actual.annotation.as_dict() == expected_annotation.as_dict()
+
+
 def test_parse__param_field_type_field_first__param_section_with_type(parse_sphinx: ParserType) -> None:
     """Parse parameters with separated types first.
 
@@ -275,6 +315,33 @@ def test_parse__param_field_type_field_first__param_section_with_type(parse_sphi
     assert actual.as_dict() == expected.as_dict()
 
 
+def test_parse__param_field_type_field_first__param_section_with_type_with_parent(parse_sphinx: ParserType) -> None:
+    """Parse parameters with separated types first.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :type {SOME_NAME}: str
+        :param {SOME_NAME}: {SOME_TEXT}
+    """
+    parent_fn = Function("func", parameters=Parameters(Parameter(SOME_NAME)))
+    sections, _ = parse_sphinx(docstring, parent=parent_fn)
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    expected_annotation = ExprName("str", parent=Class("C"))
+    expected = DocstringParameter(SOME_NAME, annotation=expected_annotation, description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+    assert isinstance(actual.annotation, type(expected.annotation))
+    assert isinstance(actual.annotation, ExprName)
+    assert isinstance(actual.annotation, Expr)
+    assert actual.annotation.as_dict() == expected_annotation.as_dict()
+
+
 @pytest.mark.parametrize("union", ["str or None", "None or str", "str or int", "str or int or float"])
 def test_parse__param_field_type_field_or_none__param_section_with_optional(
     parse_sphinx: ParserType,
@@ -302,6 +369,47 @@ def test_parse__param_field_type_field_or_none__param_section_with_optional(
     assert actual.as_dict() == expected.as_dict()
 
 
+@pytest.mark.parametrize(
+    ("union", "expected_annotation"),
+    [
+        ("str or None", ExprBinOp(ExprName("str"), "|", "None")),
+        ("None or str", ExprBinOp("None", "|", ExprName("str"))),
+        ("str or int", ExprBinOp(ExprName("str"), "|", ExprName("int"))),
+        ("str or int or float", ExprBinOp(ExprBinOp(ExprName("str"), "|", ExprName("int")), "|", ExprName("float"))),
+    ],
+)
+def test_parse__param_field_type_field_or_none__param_section_with_optional_with_parent(
+    parse_sphinx: ParserType,
+    union: str,
+    expected_annotation: Expr,
+) -> None:
+    """Parse parameters with separated union types.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+        union: A parametrized union type.
+        expected_annotation: The expected annotation as an expression
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :param {SOME_NAME}: {SOME_TEXT}
+        :type {SOME_NAME}: {union}
+    """
+
+    parent_fn = Function("func", parameters=Parameters(Parameter(SOME_NAME)))
+    sections, _ = parse_sphinx(docstring, parent=parent_fn)
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    expected = DocstringParameter(SOME_NAME, annotation=expected_annotation, description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+    assert isinstance(actual.annotation, type(expected.annotation))
+    assert isinstance(actual.annotation, Expr)
+    assert actual.annotation.as_dict() == expected_annotation.as_dict()
+
+
 def test_parse__param_field_annotate_type__param_section_with_type(parse_sphinx: ParserType) -> None:
     """Parse a simple docstring.
 
@@ -421,6 +529,80 @@ def test_parse__invalid_param_field_wrong_part_count__error_message(parse_sphinx
     assert "Failed to parse field directive" in warnings[0]
 
 
+def test_parse__invalid_param_field_wrong_part_count_spaces_4__error_message(parse_sphinx: ParserType) -> None:
+    """Parse a simple docstring.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :param typing.Union[str, int] {SOME_NAME}: {SOME_TEXT}
+    """
+
+    sections, warnings = parse_sphinx(docstring)
+
+    # Assert that the warning is shown
+    assert "Failed to parse field directive" in warnings[0]
+
+    # Assert that the parameter is still collected, but ignores the invalid type
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    expected = DocstringParameter(SOME_NAME, annotation=None, description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+
+
+def test_parse__valid_param_field_part_count_3(parse_sphinx: ParserType) -> None:
+    """Parse a simple docstring.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :param typing.Union[str,int] {SOME_NAME}: {SOME_TEXT}
+    """
+
+    sections, _ = parse_sphinx(docstring)
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    expected = DocstringParameter(SOME_NAME, annotation="typing.Union[str,int]", description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+
+
+def test_parse__valid_param_field_part_count_3_with_parent(parse_sphinx: ParserType) -> None:
+    """Parse a simple docstring.
+
+    Parameters:
+        parse_sphinx: Fixture parser.
+    """
+    docstring = f"""
+        Docstring with line continuation.
+
+        :param typing.Union[str,int] {SOME_NAME}: {SOME_TEXT}
+    """
+
+    parent_fn = Function("func3", parameters=Parameters(Parameter(name=SOME_NAME)))
+    sections, _ = parse_sphinx(docstring, parent=parent_fn)
+    assert len(sections) == 2
+    assert sections[1].kind is DocstringSectionKind.parameters
+    actual = sections[1].value[0]
+    typing_expr = ExprName("typing", parent=parent_fn)
+    expected_annotation = ExprSubscript(
+        left=ExprAttribute(values=[typing_expr, ExprName("Union", parent=typing_expr)]),
+        slice=ExprTuple([ExprName("str", parent=parent_fn), ExprName("int", parent=parent_fn)], implicit=True),
+    )
+    expected = DocstringParameter(SOME_NAME, annotation=expected_annotation, description=SOME_TEXT)
+    assert isinstance(actual, type(expected))
+    assert actual.as_dict() == expected.as_dict()
+
+
 def test_parse__param_twice__error_message(parse_sphinx: ParserType) -> None:
     """Parse a simple docstring.
 
