@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import sys
 from copy import deepcopy
 from textwrap import dedent
 
@@ -9,12 +10,18 @@ import pytest
 
 from griffe import (
     Attribute,
+    Class,
     Docstring,
+    Function,
     GriffeLoader,
     Module,
     NameResolutionError,
     Parameter,
+    ParameterKind,
     Parameters,
+    TypeParameter,
+    TypeParameterKind,
+    TypeParameters,
     module_vtree,
     temporary_inspected_module,
     temporary_pypackage,
@@ -58,8 +65,8 @@ def test_handle_aliases_chain_in_has_docstrings() -> None:
     with temporary_pypackage("package", ["mod_a.py", "mod_b.py"]) as tmp_package:
         mod_a = tmp_package.path / "mod_a.py"
         mod_b = tmp_package.path / "mod_b.py"
-        mod_a.write_text("from .mod_b import someobj")
-        mod_b.write_text("from somelib import someobj")
+        mod_a.write_text("from .mod_b import someobj", encoding="utf8")
+        mod_b.write_text("from somelib import someobj", encoding="utf8")
 
         loader = GriffeLoader(search_paths=[tmp_package.tmpdir])
         package = loader.load(tmp_package.name)
@@ -73,8 +80,8 @@ def test_has_docstrings_does_not_trigger_alias_resolution() -> None:
     with temporary_pypackage("package", ["mod_a.py", "mod_b.py"]) as tmp_package:
         mod_a = tmp_package.path / "mod_a.py"
         mod_b = tmp_package.path / "mod_b.py"
-        mod_a.write_text("from .mod_b import someobj")
-        mod_b.write_text("from somelib import someobj")
+        mod_a.write_text("from .mod_b import someobj", encoding="utf8")
+        mod_b.write_text("from somelib import someobj", encoding="utf8")
 
         loader = GriffeLoader(search_paths=[tmp_package.tmpdir])
         package = loader.load(tmp_package.name)
@@ -557,3 +564,95 @@ def test_resolving_never_raises_alias_errors() -> None:
         },
     ) as module:
         assert module["A.__init__"].resolve("pd") == "package.mod.pd"
+
+
+def test_building_function_and_class_signatures() -> None:
+    """Test the construction of a class/function signature."""
+    # Test simple function signatures.
+    simple_params = Parameters(
+        Parameter("x", annotation="int"),
+        Parameter("y", annotation="int", default="0"),
+    )
+    simple_func = Function("simple_function", parameters=simple_params, returns="int")
+    assert simple_func.signature() == "simple_function(x: int, y: int = 0) -> int"
+
+    # Test class signatures.
+    init = Function("__init__", parameters=simple_params, returns="None")
+    cls = Class("TestClass")
+    cls.set_member("__init__", init)
+    assert cls.signature() == "TestClass(x: int, y: int = 0)"
+
+    # Create a more complex function with various parameter types.
+    params = Parameters(
+        Parameter("a", kind=ParameterKind.positional_only),
+        Parameter("b", kind=ParameterKind.positional_only, annotation="int", default="0"),
+        Parameter("c", kind=ParameterKind.positional_or_keyword),
+        Parameter("d", kind=ParameterKind.positional_or_keyword, annotation="str", default="''"),
+        Parameter("args", kind=ParameterKind.var_positional),
+        Parameter("e", kind=ParameterKind.keyword_only),
+        Parameter("f", kind=ParameterKind.keyword_only, annotation="bool", default="False"),
+        Parameter("kwargs", kind=ParameterKind.var_keyword),
+    )
+
+    func = Function("test_function", parameters=params, returns="None")
+    expected = "test_function(a, b: int = 0, /, c, d: str = '', *args, e, f: bool = False, **kwargs) -> None"
+    assert func.signature() == expected
+
+
+def test_set_type_parameters() -> None:
+    """We can set type parameters."""
+    type_parameters = TypeParameters()
+    # Does not exist yet.
+    type_parameters["x"] = TypeParameter(name="x", kind=TypeParameterKind.type_var)
+    assert "x" in type_parameters
+    # Already exists, by name.
+    type_parameters["x"] = TypeParameter(name="x", kind=TypeParameterKind.type_var)
+    assert "x" in type_parameters
+    assert len(type_parameters) == 1
+    # Already exists, by name, with different kind.
+    type_parameters["x"] = TypeParameter(name="x", kind=TypeParameterKind.param_spec)
+    assert "x" in type_parameters
+    assert len(type_parameters) == 1
+    # Already exists, by index.
+    type_parameters[0] = TypeParameter(name="y", kind=TypeParameterKind.type_var)
+    assert "y" in type_parameters
+    assert len(type_parameters) == 1
+
+
+def test_delete_type_parameters() -> None:
+    """We can delete type parameters."""
+    type_parameters = TypeParameters()
+    # By name.
+    type_parameters["x"] = TypeParameter(name="x", kind=TypeParameterKind.type_var)
+    del type_parameters["x"]
+    assert "x" not in type_parameters
+    assert len(type_parameters) == 0
+    # By index.
+    type_parameters["x"] = TypeParameter(name="x", kind=TypeParameterKind.type_var)
+    del type_parameters[0]
+    assert "x" not in type_parameters
+    assert len(type_parameters) == 0
+
+
+# YORE: EOL 3.11: Remove line.
+@pytest.mark.skipif(sys.version_info < (3, 12), reason="Python less than 3.12 does not have PEP 695 generics")
+def test_annotation_resolution() -> None:
+    """Names are correctly resolved in the annotation scope of an object."""
+    with temporary_visited_module(
+        """
+        class C[T]:
+            class D[T]:
+                def func[Y](self, arg1: T, arg2: Y): pass
+            def func[Z](arg1: T, arg2: Y): pass
+        """,
+    ) as module:
+        assert module["C.D"].resolve("T") == "module.C.D[T]"
+
+        assert module["C.D.func"].resolve("T") == "module.C.D[T]"
+        assert module["C.D.func"].resolve("Y") == "module.C.D.func[Y]"
+
+        assert module["C"].resolve("T") == "module.C[T]"
+
+        assert module["C.func"].resolve("T") == "module.C[T]"
+        with pytest.raises(NameResolutionError):
+            module["C.func"].resolve("Y")
